Struct GlobalListContents
pub struct GlobalListContents { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
A container representing the current contents of the list of globals
Implementations
impl GlobalListContents
impl GlobalListContents
pub fn with_list<T, F>(&self, f: F) -> T
pub fn with_list<T, F>(&self, f: F) -> T
Access the list of globals
Your closure is invoked on the global list, and its return value is forwarded to the return value of this function. This allows you to process the list without making a copy.
pub fn clone_list(&self) -> Vec<Global>
pub fn clone_list(&self) -> Vec<Global>
Get a copy of the contents of the list of globals.