Struct GlobalList
pub struct GlobalList { /* private fields */ }wayland and Linux only.Expand description
A helper for global initialization.
See the module level documentation for more.
Implementations
impl GlobalList
impl GlobalList
pub fn contents(&self) -> &GlobalListContents
pub fn contents(&self) -> &GlobalListContents
Access the contents of the list of globals
pub fn bind<I, State, U>(
&self,
qh: &QueueHandle<State>,
version: RangeInclusive<u32>,
udata: U,
) -> Result<I, BindError>
pub fn bind<I, State, U>( &self, qh: &QueueHandle<State>, version: RangeInclusive<u32>, udata: U, ) -> Result<I, BindError>
Binds a global, returning a new protocol object associated with the global.
The version specifies the range of versions that should be bound. This function will guarantee the
version of the returned protocol object is the lower of the maximum requested version and the advertised
version.
If the lower bound of the version is less than the version advertised by the server, then
BindError::UnsupportedVersion is returned.
Multi-instance/Device globals.
This function is not intended to be used with globals that have multiple instances such as wl_output
and wl_seat. These types of globals need their own initialization mechanism because these
multi-instance globals may be removed at runtime. To handle then, you should instead rely on the
Dispatch implementation for WlRegistry of your State.
Panics
This function will panic if the maximum requested version is greater than the known maximum version of the interface. The known maximum version is determined by the code generated using wayland-scanner.
pub fn registry(&self) -> &WlRegistry
pub fn registry(&self) -> &WlRegistry
Returns the WlRegistry protocol object.
This may be used if more direct control when creating globals is needed.
pub fn destroy(self)
pub fn destroy(self)
Tries to destroy the WlRegistry protocol object.
If successful no new events will be emitted and the GlobalListContent
will not be updated anymore. Other proocol objects are not affected.
This might end up doing nothing if the compositor doesn’t support wl_fixes
in which case the registry cannot be destroyed without closing the connection.